;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

;old-cus-dep-hash: #s(hash-table test equal size 16 data ("/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-debug.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-sysdep.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-ids.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-parse.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/iso-sgml.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-edit.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-dtd.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml.el" ((sgml-mode-hook . "psgml") (sgml-xml-declaration . "psgml") (sgml-declaration . "psgml") (sgml-validate-files . "psgml") (sgml-xml-validate-command . "psgml") (sgml-validate-command . "psgml") (sgml-custom-dtd . "psgml") (sgml-custom-markup . "psgml") (sgml-public-transliterations . "psgml") (sgml-local-ecat-files . "psgml") (sgml-ecat-files . "psgml") (sgml-catalog-files . "psgml") (sgml-local-catalogs . "psgml") (sgml-public-map . "psgml") (sgml-system-path . "psgml") (sgml-inhibit-indent-tags . "psgml") (sgml-trace-entity-lookup . "psgml") (sgml-recompile-out-of-date-cdtd . "psgml") (sgml-ignore-undefined-elements . "psgml") (sgml-warn-about-undefined-entities . "psgml") (sgml-warn-about-undefined-elements . "psgml") (sgml-leave-point-after-insert . "psgml") (sgml-omittag-transparent . "psgml") (sgml-balanced-tag-edit . "psgml") (sgml-auto-insert-required-elements . "psgml") (sgml-general-insert-case . "psgml") (sgml-normalize-trims . "psgml") (sgml-tag-region-if-active . "psgml") (sgml-offer-save . "psgml") (sgml-auto-activate-dtd . "psgml") (sgml-live-element-indicator . "psgml") (sgml-set-face . "psgml") (sgml-markup-faces . "psgml") (sgml-default-doctype-name . "psgml") (sgml-range-indicator-max-length . "psgml") (sgml-system-identifiers-are-preferred . "psgml") (sgml-insert-end-tag-on-new-line . "psgml") (sgml-insert-missing-element-comment . "psgml") (psgml-dtd . "psgml") (psgml-insert . "psgml") (psgml . "psgml") (sgml . "psgml")) "/home/nk/pkg-build/test/xemacs-packages/psgml/auto-autoloads.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-fs.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-info.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-xemacs.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-charent.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/_pkg.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-api.el" nil "/home/nk/pkg-build/test/xemacs-packages/psgml/psgml-html.el" ((html-helper-significant-tag-face . "psgml-html") (html-helper-link-face . "psgml-html") (html-helper-strikethrough-face . "psgml-html") (html-helper-underline-face . "psgml-html") (html-helper-italic-face . "psgml-html") (html-helper-bold-face . "psgml-html") (psgml-html-faces . "psgml-html") (html-helper-user-menu . "psgml-html") (html-helper-use-expert-menu . "psgml-html") (html-helper-types-to-install . "psgml-html") (html-helper-timestamp-end . "psgml-html") (html-helper-timestamp-start . "psgml-html") (html-helper-new-buffer-template . "psgml-html") (html-helper-timestamp-hook . "psgml-html") (html-helper-build-new-buffer . "psgml-html") (html-helper-do-write-file-hooks . "psgml-html") (html-helper-htmldtd-version . "psgml-html") (html-helper-address-string . "psgml-html") (psgml-html . "psgml-html") (html . "psgml-html"))))
(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'hypermedia '("psgml-html"))
(custom-add-loads 'languages '("psgml"))
(custom-add-loads 'psgml-html-faces '("psgml-html"))
(custom-add-loads 'psgml-dtd '("psgml"))
(custom-add-loads 'html '("psgml-html"))
(custom-add-loads 'psgml '("psgml-html" "psgml"))
(custom-add-loads 'psgml-insert '("psgml"))
(custom-add-loads 'psgml-html '("psgml-html"))
(custom-add-loads 'faces '("psgml-html"))
(custom-add-loads 'sgml '("psgml-html" "psgml"))

;;; custom-load.el ends here
